/*
 * atmo.c: A plugin for the Video Disk Recorder
 *
 * See the README file for copyright information and how to reach the author.
 *
 * $Id$
 */

#include <getopt.h>
#include <arpa/inet.h>
#include <vdr/plugin.h>

#include "setup.h"
#include "thread.h"
#include "atmo.h"

// setup configuration
cAtmoSetup AtmoSetup;

// for sending data
struct sockaddr_in address;
const char *arg_serial;

// --- cPluginAtmo -----------------------------------------------------------

cPluginAtmo::cPluginAtmo(void)
{
  // Initialize any member variables here.
  // DON'T DO ANYTHING ELSE THAT MAY HAVE SIDE EFFECTS, REQUIRE GLOBAL
  // VDR OBJECTS TO EXIST OR PRODUCE ANY OUTPUT!

  address.sin_port = 0; // unused  
  arg_serial = NULL;
  AtmoThread = NULL;
}

cPluginAtmo::~cPluginAtmo()
{
  // Clean up after yourself!
  delete AtmoThread;
}

const char *cPluginAtmo::CommandLineHelp(void)
{
  // Return a string that describes all known command line options.
  return "  -n IP/PORT, --net=IP:PORT  send atmolight-data over network (e.g. 192.168.0.1:1234)\n"
         "  -s DEV,     --serial=DEV   send atmolight-data to serial device (e.g. /dev/ttyS1)\n";
}

bool cPluginAtmo::ProcessArgs(int argc, char *argv[])
{
  // Implement command line argument processing here if applicable.
  static struct option long_options[] = {
      { "net",    required_argument, NULL, 'n' },
      { "serial", required_argument, NULL, 's' },
      { NULL }
  };

  int c;
  while ((c=getopt_long(argc, argv, "n:s:", long_options, NULL)) != -1)
  {
    switch (c)
    {
      case 'n': // network
		  char ip[16];
                int port;
                if (sscanf(optarg,"%15[^:]:%d", ip, &port) < 2) return false;
                address.sin_family = AF_INET;
                address.sin_port = htons(port);
                if (0 == inet_aton(ip, &address.sin_addr)) return false;
      break;

      case 's': // serial
                arg_serial = optarg;
      break;

      default: return false;
    }
  }
  return true;
}

bool cPluginAtmo::Initialize(void)
{
  // Initialize any background activities the plugin shall perform.
  return true;
}

bool cPluginAtmo::Start(void)
{
  // Start any background activities the plugin shall perform.
  
  AtmoThread = new cAtmoThread();
  AtmoThread->Start();
  return true;
}

void cPluginAtmo::Stop(void)
{
  // Stop any background activities the plugin shall perform.
}

void cPluginAtmo::Housekeeping(void)
{
  // Perform any cleanup or other regular tasks.
}

void cPluginAtmo::MainThreadHook(void)
{
  // Perform actions in the context of the main program thread.
  // WARNING: Use with great care - see PLUGINS.html!
}

cString cPluginAtmo::Active(void)
{
  // Return a message string if shutdown should be postponed
  return NULL;
}

const char *cPluginAtmo::MainMenuEntry(void)
{
  if (true == AtmoSetup.atmo_on) { return "Atmolight ausschalten"; } // tr("")
  else { return "Atmolight einschalten"; } // tr("")
  // return NULL; // if no "main menu entry"
}

cOsdObject *cPluginAtmo::MainMenuAction(void)
{
  // Perform the action when selected from the main VDR menu.
  AtmoSetup.atmo_on = AtmoSetup.atmo_on ? false : true;
  return NULL;
}

cMenuSetupPage *cPluginAtmo::SetupMenu(void)
{
  // Return a setup menu in case the plugin supports one.
  return new cMenuSetupAtmo;
}

bool cPluginAtmo::SetupParse(const char *Name, const char *Value)
{
  // Parse your own setup parameters and store their values.
  return AtmoSetup.SetupParse(Name, Value);
}

bool cPluginAtmo::Service(const char *Id, void *Data)
{
  // Handle custom service requests from other plugins
  return false;
}

const char **cPluginAtmo::SVDRPHelpPages(void)
{
  // Return help text for SVDRP commands this plugin implements
  return NULL;
}

cString cPluginAtmo::SVDRPCommand(const char *Command, const char *Option, int &ReplyCode)
{
  // Process SVDRP commands this plugin implements
  return NULL;
}

VDRPLUGINCREATOR(cPluginAtmo); // Don't touch this!
